@@ -30,6 +30,9 @@ def _render(template, obj, context):
     template_variants = _get_template_names(obj, template)
     return render_to_response(template_variants, context_instance=context)
 
+def get_prepared_errors(form):
+    return dict([(unicode(f), unicode(form.errors[f][0]),) for f in form.errors]) #todo: get rif of errors[f][0]
+
 
 #==============================================================================
 
@@ -58,6 +61,7 @@ def edit_album(request, obj, album_site, context, template_name):
 
 
 @login_required
+@ajax_request
 @album_site_method()
 def upload_main_image(request, obj, album_site, context):
     ''' Upload 1 image and make it main image in gallery '''
@@ -77,7 +81,7 @@ def upload_main_image(request, obj, album_site, context):
             return HttpResponseRedirect(success_url) # Redirect after POST
         else:
             if request.is_ajax():
-                return HttpResponse(form.errors.as_text())
+                return get_prepared_errors(form)
     else:
         form = album_site.upload_form_class()
 
@@ -89,6 +93,7 @@ def upload_main_image(request, obj, album_site, context):
 
 
 @login_required
+@ajax_request
 @album_site_method()
 def upload_zip(request, obj, album_site, context):
     ''' Upload zip archive with images, extract them, check if they are correct
@@ -108,7 +113,7 @@ def upload_zip(request, obj, album_site, context):
             return HttpResponseRedirect(success_url)
         else:
             if request.is_ajax():
-                return HttpResponse(form.errors.as_text())
+                return get_prepared_errors(form)
     else:
         form = form_class(request.user, obj)
 
@@ -120,6 +125,7 @@ def upload_zip(request, obj, album_site, context):
     return _render('upload_zip.html', obj, context)
 
 @login_required
+@ajax_request
 @album_site_method()
 def upload_images(request, obj, album_site, context):
     ''' Upload several images at once '''
@@ -145,7 +151,7 @@ def upload_images(request, obj, album_site, context):
             return HttpResponseRedirect(success_url) # Redirect after POST
         else:
             if request.is_ajax():
-                return HttpResponse(formset.errors.as_text())
+                return get_prepared_errors(formset)
     else:
         formset = FormsetCls(queryset = AttachedImage.objects.none())
 
